Span

Struct Span 

pub struct Span { /* private fields */ }
A span consists of a list of styles to apply to an inner list of inline content.

Implementations

Source

impl Span

pub fn with_style(inner: &str, style: SpanStyle) -> Self

Create a new span, with the provided style, that includes a Text instance.

pub fn with_styles(inner: &str, styles: Vec<SpanStyle>) -> Self

Create a new span, with the provided styles, that includes a Text instance.

pub fn inner_with_style(inner: InlineContent, style: SpanStyle) -> Self

Create a new span, with the provided style, that includes a InlineContent instance.

pub fn inner_with_styles(inner: InlineContent, styles: Vec<SpanStyle>) -> Self

Create a new span, with the provided style, that includes a InlineContent instance.

pub fn space() -> Self

Create a new span containing simply a space character.