pub struct Span { /* private fields */ }Expand description
A span consists of a list of styles to apply to an inner list of inline content.
Implementations
Sourceimpl Span
impl Span
Sourcepub fn with_style(inner: &str, style: SpanStyle) -> Self
pub fn with_style(inner: &str, style: SpanStyle) -> Self
Create a new span, with the provided style, that includes a Text instance.
Sourcepub fn with_styles(inner: &str, styles: Vec<SpanStyle>) -> Self
pub fn with_styles(inner: &str, styles: Vec<SpanStyle>) -> Self
Create a new span, with the provided styles, that includes a Text instance.
Sourcepub fn inner_with_style(inner: InlineContent, style: SpanStyle) -> Self
pub fn inner_with_style(inner: InlineContent, style: SpanStyle) -> Self
Create a new span, with the provided style, that includes a InlineContent instance.
Sourcepub fn inner_with_styles(inner: InlineContent, styles: Vec<SpanStyle>) -> Self
pub fn inner_with_styles(inner: InlineContent, styles: Vec<SpanStyle>) -> Self
Create a new span, with the provided style, that includes a InlineContent instance.